/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.books.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Model definition for Bookshelf.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Books API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Bookshelf extends GenericJson {

  /**
   * Whether this bookshelf is PUBLIC or PRIVATE.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String access;

  /**
   * Created time for this bookshelf (formatted UTC timestamp with millisecond resolution).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime created;

  /**
   * Description of this bookshelf.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * Id of this bookshelf, only unique by user.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer id;

  /**
   * Resource type for bookshelf metadata.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * URL to this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * Title of this bookshelf.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * Last modified time of this bookshelf (formatted UTC timestamp with millisecond resolution).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime updated;

  /**
   * Number of volumes in this bookshelf.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer volumeCount;

  /**
   * Last time a volume was added or removed from this bookshelf (formatted UTC timestamp with
   * millisecond resolution).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime volumesLastUpdated;

  /**
   * Whether this bookshelf is PUBLIC or PRIVATE.
   * The value returned may be {@code null}.
   */
  public String getAccess() {
    return access;
  }

  /**
   * Whether this bookshelf is PUBLIC or PRIVATE.
   * The value set may be {@code null}.
   */
  public Bookshelf setAccess(String access) {
    this.access = access;
    return this;
  }

  /**
   * Created time for this bookshelf (formatted UTC timestamp with millisecond resolution).
   * The value returned may be {@code null}.
   */
  public DateTime getCreated() {
    return created;
  }

  /**
   * Created time for this bookshelf (formatted UTC timestamp with millisecond resolution).
   * The value set may be {@code null}.
   */
  public Bookshelf setCreated(DateTime created) {
    this.created = created;
    return this;
  }

  /**
   * Description of this bookshelf.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * Description of this bookshelf.
   * The value set may be {@code null}.
   */
  public Bookshelf setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * Id of this bookshelf, only unique by user.
   * The value returned may be {@code null}.
   */
  public Integer getId() {
    return id;
  }

  /**
   * Id of this bookshelf, only unique by user.
   * The value set may be {@code null}.
   */
  public Bookshelf setId(Integer id) {
    this.id = id;
    return this;
  }

  /**
   * Resource type for bookshelf metadata.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Resource type for bookshelf metadata.
   * The value set may be {@code null}.
   */
  public Bookshelf setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * URL to this resource.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * URL to this resource.
   * The value set may be {@code null}.
   */
  public Bookshelf setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * Title of this bookshelf.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * Title of this bookshelf.
   * The value set may be {@code null}.
   */
  public Bookshelf setTitle(String title) {
    this.title = title;
    return this;
  }

  /**
   * Last modified time of this bookshelf (formatted UTC timestamp with millisecond resolution).
   * The value returned may be {@code null}.
   */
  public DateTime getUpdated() {
    return updated;
  }

  /**
   * Last modified time of this bookshelf (formatted UTC timestamp with millisecond resolution).
   * The value set may be {@code null}.
   */
  public Bookshelf setUpdated(DateTime updated) {
    this.updated = updated;
    return this;
  }

  /**
   * Number of volumes in this bookshelf.
   * The value returned may be {@code null}.
   */
  public Integer getVolumeCount() {
    return volumeCount;
  }

  /**
   * Number of volumes in this bookshelf.
   * The value set may be {@code null}.
   */
  public Bookshelf setVolumeCount(Integer volumeCount) {
    this.volumeCount = volumeCount;
    return this;
  }

  /**
   * Last time a volume was added or removed from this bookshelf (formatted UTC timestamp with
   * millisecond resolution).
   * The value returned may be {@code null}.
   */
  public DateTime getVolumesLastUpdated() {
    return volumesLastUpdated;
  }

  /**
   * Last time a volume was added or removed from this bookshelf (formatted UTC timestamp with
   * millisecond resolution).
   * The value set may be {@code null}.
   */
  public Bookshelf setVolumesLastUpdated(DateTime volumesLastUpdated) {
    this.volumesLastUpdated = volumesLastUpdated;
    return this;
  }

}
