/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.books.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for ConcurrentAccessRestriction.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Books API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class ConcurrentAccessRestriction extends GenericJson {

  /**
   * Whether access is granted for this (user, device, volume).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean deviceAllowed;

  /**
   * Resource type.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The maximum number of concurrent access licenses for this volume.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer maxConcurrentDevices;

  /**
   * Error/warning message.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String message;

  /**
   * Client nonce for verification. Download access and client-validation only.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String nonce;

  /**
   * Error/warning reason code.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String reasonCode;

  /**
   * Whether this volume has any concurrent access restrictions.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean restricted;

  /**
   * Response signature.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String signature;

  /**
   * Client app identifier for verification. Download access and client-validation only.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String source;

  /**
   * Time in seconds for license auto-expiration.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer timeWindowSeconds;

  /**
   * Identifies the volume for which this entry applies.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String volumeId;

  /**
   * Whether access is granted for this (user, device, volume).
   * The value returned may be {@code null}.
   */
  public Boolean getDeviceAllowed() {
    return deviceAllowed;
  }

  /**
   * Whether access is granted for this (user, device, volume).
   * The value set may be {@code null}.
   */
  public ConcurrentAccessRestriction setDeviceAllowed(Boolean deviceAllowed) {
    this.deviceAllowed = deviceAllowed;
    return this;
  }

  /**
   * Resource type.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Resource type.
   * The value set may be {@code null}.
   */
  public ConcurrentAccessRestriction setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The maximum number of concurrent access licenses for this volume.
   * The value returned may be {@code null}.
   */
  public Integer getMaxConcurrentDevices() {
    return maxConcurrentDevices;
  }

  /**
   * The maximum number of concurrent access licenses for this volume.
   * The value set may be {@code null}.
   */
  public ConcurrentAccessRestriction setMaxConcurrentDevices(Integer maxConcurrentDevices) {
    this.maxConcurrentDevices = maxConcurrentDevices;
    return this;
  }

  /**
   * Error/warning message.
   * The value returned may be {@code null}.
   */
  public String getMessage() {
    return message;
  }

  /**
   * Error/warning message.
   * The value set may be {@code null}.
   */
  public ConcurrentAccessRestriction setMessage(String message) {
    this.message = message;
    return this;
  }

  /**
   * Client nonce for verification. Download access and client-validation only.
   * The value returned may be {@code null}.
   */
  public String getNonce() {
    return nonce;
  }

  /**
   * Client nonce for verification. Download access and client-validation only.
   * The value set may be {@code null}.
   */
  public ConcurrentAccessRestriction setNonce(String nonce) {
    this.nonce = nonce;
    return this;
  }

  /**
   * Error/warning reason code.
   * The value returned may be {@code null}.
   */
  public String getReasonCode() {
    return reasonCode;
  }

  /**
   * Error/warning reason code.
   * The value set may be {@code null}.
   */
  public ConcurrentAccessRestriction setReasonCode(String reasonCode) {
    this.reasonCode = reasonCode;
    return this;
  }

  /**
   * Whether this volume has any concurrent access restrictions.
   * The value returned may be {@code null}.
   */
  public Boolean getRestricted() {
    return restricted;
  }

  /**
   * Whether this volume has any concurrent access restrictions.
   * The value set may be {@code null}.
   */
  public ConcurrentAccessRestriction setRestricted(Boolean restricted) {
    this.restricted = restricted;
    return this;
  }

  /**
   * Response signature.
   * The value returned may be {@code null}.
   */
  public String getSignature() {
    return signature;
  }

  /**
   * Response signature.
   * The value set may be {@code null}.
   */
  public ConcurrentAccessRestriction setSignature(String signature) {
    this.signature = signature;
    return this;
  }

  /**
   * Client app identifier for verification. Download access and client-validation only.
   * The value returned may be {@code null}.
   */
  public String getSource() {
    return source;
  }

  /**
   * Client app identifier for verification. Download access and client-validation only.
   * The value set may be {@code null}.
   */
  public ConcurrentAccessRestriction setSource(String source) {
    this.source = source;
    return this;
  }

  /**
   * Time in seconds for license auto-expiration.
   * The value returned may be {@code null}.
   */
  public Integer getTimeWindowSeconds() {
    return timeWindowSeconds;
  }

  /**
   * Time in seconds for license auto-expiration.
   * The value set may be {@code null}.
   */
  public ConcurrentAccessRestriction setTimeWindowSeconds(Integer timeWindowSeconds) {
    this.timeWindowSeconds = timeWindowSeconds;
    return this;
  }

  /**
   * Identifies the volume for which this entry applies.
   * The value returned may be {@code null}.
   */
  public String getVolumeId() {
    return volumeId;
  }

  /**
   * Identifies the volume for which this entry applies.
   * The value set may be {@code null}.
   */
  public ConcurrentAccessRestriction setVolumeId(String volumeId) {
    this.volumeId = volumeId;
    return this;
  }

}
