/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.books.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for Review.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Books API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Review extends GenericJson {

  /**
   * Author of this review.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Author author;

  /**
   * Review text.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String content;

  /**
   * Date of this review.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String date;

  /**
   * URL for the full review text, for reviews gathered from the web.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String fullTextUrl;

  /**
   * Resource type for a review.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Star rating for this review. Possible values are ONE, TWO, THREE, FOUR, FIVE or NOT_RATED.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String rating;

  /**
   * Information regarding the source of this review, when the review is not from a Google Books
   * user.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Source source;

  /**
   * Title for this review.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * Source type for this review. Possible values are EDITORIAL, WEB_USER or GOOGLE_USER.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String type;

  /**
   * Volume that this review is for.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String volumeId;

  /**
   * Author of this review.
   * The value returned may be {@code null}.
   */
  public Author getAuthor() {
    return author;
  }

  /**
   * Author of this review.
   * The value set may be {@code null}.
   */
  public Review setAuthor(Author author) {
    this.author = author;
    return this;
  }

  /**
   * Review text.
   * The value returned may be {@code null}.
   */
  public String getContent() {
    return content;
  }

  /**
   * Review text.
   * The value set may be {@code null}.
   */
  public Review setContent(String content) {
    this.content = content;
    return this;
  }

  /**
   * Date of this review.
   * The value returned may be {@code null}.
   */
  public String getDate() {
    return date;
  }

  /**
   * Date of this review.
   * The value set may be {@code null}.
   */
  public Review setDate(String date) {
    this.date = date;
    return this;
  }

  /**
   * URL for the full review text, for reviews gathered from the web.
   * The value returned may be {@code null}.
   */
  public String getFullTextUrl() {
    return fullTextUrl;
  }

  /**
   * URL for the full review text, for reviews gathered from the web.
   * The value set may be {@code null}.
   */
  public Review setFullTextUrl(String fullTextUrl) {
    this.fullTextUrl = fullTextUrl;
    return this;
  }

  /**
   * Resource type for a review.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Resource type for a review.
   * The value set may be {@code null}.
   */
  public Review setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Star rating for this review. Possible values are ONE, TWO, THREE, FOUR, FIVE or NOT_RATED.
   * The value returned may be {@code null}.
   */
  public String getRating() {
    return rating;
  }

  /**
   * Star rating for this review. Possible values are ONE, TWO, THREE, FOUR, FIVE or NOT_RATED.
   * The value set may be {@code null}.
   */
  public Review setRating(String rating) {
    this.rating = rating;
    return this;
  }

  /**
   * Information regarding the source of this review, when the review is not from a Google Books
   * user.
   * The value returned may be {@code null}.
   */
  public Source getSource() {
    return source;
  }

  /**
   * Information regarding the source of this review, when the review is not from a Google Books
   * user.
   * The value set may be {@code null}.
   */
  public Review setSource(Source source) {
    this.source = source;
    return this;
  }

  /**
   * Title for this review.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * Title for this review.
   * The value set may be {@code null}.
   */
  public Review setTitle(String title) {
    this.title = title;
    return this;
  }

  /**
   * Source type for this review. Possible values are EDITORIAL, WEB_USER or GOOGLE_USER.
   * The value returned may be {@code null}.
   */
  public String getType() {
    return type;
  }

  /**
   * Source type for this review. Possible values are EDITORIAL, WEB_USER or GOOGLE_USER.
   * The value set may be {@code null}.
   */
  public Review setType(String type) {
    this.type = type;
    return this;
  }

  /**
   * Volume that this review is for.
   * The value returned may be {@code null}.
   */
  public String getVolumeId() {
    return volumeId;
  }

  /**
   * Volume that this review is for.
   * The value set may be {@code null}.
   */
  public Review setVolumeId(String volumeId) {
    this.volumeId = volumeId;
    return this;
  }

  /**
   * Author of this review.
   */
  public static final class Author extends GenericJson {

    /**
     * Name of this person.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String displayName;

    /**
     * Name of this person.
     * The value returned may be {@code null}.
     */
    public String getDisplayName() {
      return displayName;
    }

    /**
     * Name of this person.
     * The value set may be {@code null}.
     */
    public Author setDisplayName(String displayName) {
      this.displayName = displayName;
      return this;
    }

  }

  /**
   * Information regarding the source of this review, when the review is not from a Google Books user.
   */
  public static final class Source extends GenericJson {

    /**
     * Name of the source.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String description;

    /**
     * Extra text about the source of the review.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String extraDescription;

    /**
     * URL of the source of the review.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String url;

    /**
     * Name of the source.
     * The value returned may be {@code null}.
     */
    public String getDescription() {
      return description;
    }

    /**
     * Name of the source.
     * The value set may be {@code null}.
     */
    public Source setDescription(String description) {
      this.description = description;
      return this;
    }

    /**
     * Extra text about the source of the review.
     * The value returned may be {@code null}.
     */
    public String getExtraDescription() {
      return extraDescription;
    }

    /**
     * Extra text about the source of the review.
     * The value set may be {@code null}.
     */
    public Source setExtraDescription(String extraDescription) {
      this.extraDescription = extraDescription;
      return this;
    }

    /**
     * URL of the source of the review.
     * The value returned may be {@code null}.
     */
    public String getUrl() {
      return url;
    }

    /**
     * URL of the source of the review.
     * The value set may be {@code null}.
     */
    public Source setUrl(String url) {
      this.url = url;
      return this;
    }

  }

}
